==> derivx-0.3.3-cp37-cp37m-win_amd64.whl: derivx-0.3.3.data/data/Lib/site-packages/derivx/readme.md <==
# DerivX
V0.3.3-Beta Build 20210930

© 2021-2021 Xu Rendong. All Rights Reserved.

### Project Summary
Derivatives Pricing Engine.
+ Plain Vanilla European / American options portfolio calculation.
+ Plain Vanilla European / American option pricing and greek value calculation.
+ Exotic Autocall Phoenix / Snowball option pricing and greek value calculation.
+ Stochastic Diffusion Processes and Stochastic Volatility Models.
+ Interfaces and examples for C++, Python, JavaScript.

### Install
##### C++:
```bash

```

##### Python:
```bash
pip install derivx
```

##### JavaScript:
```bash
npm install derivx
```

### Usage
##### C++:
```c++

```

##### Python:
```python
import derivx
print(derivx.Version())
```
For more usages please refer to examples in [derivx_py](https://github.com/xurendong/derivx/tree/main/exe/windows/bin/derivx_py) folder.

DerivX is not dependent on numpy, pandas and matplotlib, but if you want to run examples, you'd better install them with:
```bash
pip install numpy pandas matplotlib
```

##### JavaScript:
```javascript
const derivx = require('derivx')
console.log(derivx.Version())
```
For more usages please refer to examples in [derivx_js](https://github.com/xurendong/derivx/tree/main/exe/windows/bin/derivx_js) folder.

DerivX is not dependent on numjs, but if you want to run examples, you'd better install it with:
```bash
npm install git+https://github.com/nicolaspanel/numjs.git
```

### Changes
Please refer to [changes](https://github.com/xurendong/derivx/blob/main/changes.txt) file.

### Benchmark
Please refer to [benchmark](https://github.com/xurendong/derivx/blob/main/benchmark.md) file.

### Contact Information
QQ: 277195007, WeChat: xrd_ustc, E-mail: xrd@ustc.edu

==> derivx-0.3.5-cp37-cp37m-win_amd64.whl: derivx-0.3.5.data/data/Lib/site-packages/derivx/readme.md <==
# DerivX
V0.3.5-Beta Build 20211110

© 2021-2021 Xu Rendong. All Rights Reserved.

### Project Summary
Derivatives Pricing Engine.
+ Single Barrier European option pricing.
+ Plain Vanilla European / American options portfolio calculation.
+ Plain Vanilla European / American option pricing and greek value calculation.
+ Exotic Autocall Booster / Phoenix / Snowball option pricing and greek value calculation.
+ Stochastic Diffusion Processes and Stochastic Volatility Models.
+ Interfaces and examples for C++, Python, JavaScript.

### Install
##### C++:
```bash

```

##### Python:
```bash
pip install derivx
```

##### JavaScript:
```bash
npm install derivx
```

### Usage
##### C++:
```c++

```

##### Python:
```python
import derivx
print(derivx.Version())
```
For more usages please refer to examples in [derivx_py](https://github.com/xurendong/derivx/tree/main/exe/windows/bin/derivx_py) folder.

DerivX is not dependent on numpy, pandas and matplotlib, but if you want to run examples, you'd better install them with:
```bash
pip install numpy pandas matplotlib
```

##### JavaScript:
```javascript
const derivx = require('derivx')
console.log(derivx.Version())
```
For more usages please refer to examples in [derivx_js](https://github.com/xurendong/derivx/tree/main/exe/windows/bin/derivx_js) folder.

DerivX is not dependent on numjs, but if you want to run examples, you'd better install it with:
```bash
npm install git+https://github.com/nicolaspanel/numjs.git
```

### Changes
Please refer to [changes](https://github.com/xurendong/derivx/blob/main/changes.txt) file.

### Benchmark
Please refer to [benchmark](https://github.com/xurendong/derivx/blob/main/benchmark.md) file.

### Contact Information
QQ: 277195007, WeChat: xrd_ustc, E-mail: xrd@ustc.edu
